@@ -11,8 +11,9 @@ from .list_provider import ListProvider
 from .multi_binding import MultiBinding
 
 if TYPE_CHECKING:
-    from opyoid.providers.providers_factories.from_registered_binding_provider_factory \
-        import FromRegisteredBindingProviderFactory
+    from opyoid.providers.providers_factories.from_registered_binding_provider_factory import (
+        FromRegisteredBindingProviderFactory,
+    )
     from opyoid.bindings.registered_multi_binding import RegisteredMultiBinding
 
 
@@ -25,9 +26,9 @@ class MultiBindingToProviderAdapter(BindingToProviderAdapter[MultiBinding]):
     def accept(self, binding: Binding[InjectedT], context: InjectionContext[InjectedT]) -> bool:
         return isinstance(binding, MultiBinding)
 
-    def create(self,
-               binding: "RegisteredMultiBinding[InjectedT]",
-               context: InjectionContext[InjectedT]) -> Provider[InjectedT]:
+    def create(
+        self, binding: "RegisteredMultiBinding[InjectedT]", context: InjectionContext[InjectedT]
+    ) -> Provider[InjectedT]:
         item_providers = []
         for sub_binding in binding.item_bindings:
             new_context = context.get_child_context(Target(sub_binding.target.type, sub_binding.target.named))
@@ -39,6 +40,8 @@ class MultiBindingToProviderAdapter(BindingToProviderAdapter[MultiBinding]):
         try:
             scope_provider = scope_context.get_provider()
         except NoBindingFound:
-            raise NonInjectableTypeError(f"Could not create a provider for {binding!r}: they are no bindings for"
-                                         f" {binding.raw_binding.scope.__name__!r}") from None
+            raise NonInjectableTypeError(
+                f"Could not create a provider for {binding!r}: they are no bindings for"
+                f" {binding.raw_binding.scope.__name__!r}"
+            ) from None
         return scope_provider.get().get_scoped_provider(unscoped_provider)
