@@ -1,6 +1,6 @@
 import attr
 
 
-@attr.s(auto_attribs=True)
+@attr.s(auto_attribs=True, kw_only=True)
 class InjectorOptions:
     auto_bindings: bool = False
